"use strict";

// Auth0Manager.js

var axios = require('axios');
var ManagementClient = require('auth0').ManagementClient;

/**
 *
 * How this works:
 *  1. Requests an access token using client_id and client_secret
 *  2. Uses the access token to create a new ManagementClient
 *  3. Use the ManagementClient to interact with the API: https://auth0.github.io/node-auth0/module-management.ManagementClient.html
 *
 */

module.exports = function () {
  var managementClient; // eslint-disable-line

  return {
    init: init
  };

  /**
   * Create a management client
   */
  function init() {
    var _this = this;
    return getToken().then(function (data) {
      return data.access_token;
    }).then(function (token) {
      var managementClient = new ManagementClient({
        domain: "".concat(process.env.AUTH0_CLIENT_DOMAIN),
        token: token,
        audience: "https://".concat(process.env.AUTH0_CLIENT_DOMAIN, "/api/v2/")
      });

      // set it so we can use it in our other methods
      _this.managementClient = managementClient;
      return true;
    })["catch"](function (err) {
      return err;
    });
  }

  /**
   * Get an access token from the Auth0 API
   * We will use this access token to connect to the management API
   * To get a token, we need to provide client_id and client_secret
   * Both of these can be found in the APIs section of Auth0 dashboard
   */
  function getToken() {
    // get the info we need
    var clientId = process.env.AUTH0_CLIENT_ID;
    var clientSecret = process.env.AUTH0_CLIENT_SECRET;
    var url = "https://".concat(process.env.AUTH0_CLIENT_DOMAIN, "/oauth/token");

    // make the call to the API via POST
    return axios.post(url, {
      client_id: clientId,
      client_secret: clientSecret,
      grant_type: 'client_credentials',
      scope: 'read:users update:users',
      audience: "https://".concat(process.env.AUTH0_CLIENT_DOMAIN, "/api/v2/")
    }).then(function (res) {
      return res.data;
    })["catch"](function (err) {
      return console.log(err);
    });
  }
}();