"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.contentfulConfig = void 0;
exports.fetchContent = fetchContent;
exports.fetchPaginatedContent = fetchPaginatedContent;
exports.getTotal = getTotal;
var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));
var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));
// Set up some global config options

var contentfulConfig = {
  live: {
    space: process.env.NEXT_PUBLIC_CONTENTFUL_SPACE_ID,
    accessToken: process.env.NEXT_PUBLIC_CONTENTFUL_ACCESS_TOKEN
  },
  preview: {
    space: process.env.NEXT_PUBLIC_CONTENTFUL_SPACE_ID,
    accessToken: process.env.NEXT_PUBLIC_CONTENTFUL_PREVIEW_ACCESS_TOKEN,
    host: 'preview.contentful.com'
  },
  global: {
    space: process.env.NEXT_PUBLIC_GLOBAL_CONTENTFUL_SPACE_ID,
    accessToken: process.env.NEXT_PUBLIC_GLOBAL_CONTENTFUL_ACCESS_TOKEN
  }
};

// Query the GraphQL API
exports.contentfulConfig = contentfulConfig;
function fetchContent(_x, _x2) {
  return _fetchContent.apply(this, arguments);
} // Run a paginated content request
function _fetchContent() {
  _fetchContent = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee(query, config) {
    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          return _context.abrupt("return", new Promise(function (resolve, reject) {
            try {
              fetch("https://graphql.contentful.com/content/v1/spaces/".concat(config.space), {
                method: 'POST',
                headers: {
                  'content-type': 'application/json',
                  authorization: "Bearer ".concat(config.accessToken)
                },
                body: JSON.stringify({
                  query: query
                })
              }).then(function (response) {
                response.json().then(function (data) {
                  if (data.errors) {
                    reject(data.data);
                  } else {
                    resolve(data.data);
                  }
                });
              });
            } catch (error) {
              reject(error);
            }
          }));
        case 1:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return _fetchContent.apply(this, arguments);
}
function fetchPaginatedContent(_x3, _x4, _x5, _x6, _x7, _x8) {
  return _fetchPaginatedContent.apply(this, arguments);
} // Get total entries for a collection
function _fetchPaginatedContent() {
  _fetchPaginatedContent = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee2(collection, perPage, page, order, config, fields) {
    var skipMultiplier, skip, query, response, paginatedEntries;
    return _regenerator["default"].wrap(function _callee2$(_context2) {
      while (1) switch (_context2.prev = _context2.next) {
        case 0:
          skipMultiplier = page === 1 ? 0 : page - 1;
          skip = skipMultiplier > 0 ? perPage * skipMultiplier : 0;
          query = "{\n      ".concat(collection, "(limit: ").concat(perPage, ", skip: ").concat(skip, ", order: ").concat(order, ") {\n        ").concat(fields, "\n      }\n    }");
          _context2.next = 5;
          return fetchContent(query, config);
        case 5:
          response = _context2.sent;
          paginatedEntries = response[collection] ? response[collection] : {
            total: 0,
            items: []
          };
          return _context2.abrupt("return", paginatedEntries);
        case 8:
        case "end":
          return _context2.stop();
      }
    }, _callee2);
  }));
  return _fetchPaginatedContent.apply(this, arguments);
}
function getTotal(_x9, _x10) {
  return _getTotal.apply(this, arguments);
}
function _getTotal() {
  _getTotal = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee3(collection, config) {
    var query, response, total;
    return _regenerator["default"].wrap(function _callee3$(_context3) {
      while (1) switch (_context3.prev = _context3.next) {
        case 0:
          query = "\n    {\n      ".concat(collection, " {\n        total\n      }\n    }\n  ");
          _context3.next = 3;
          return fetchContent(query, config);
        case 3:
          response = _context3.sent;
          total = response[collection].total ? response[collection].total : 0;
          return _context3.abrupt("return", total);
        case 6:
        case "end":
          return _context3.stop();
      }
    }, _callee3);
  }));
  return _getTotal.apply(this, arguments);
}