// Auth0Manager.js

const axios = require('axios')
const ManagementClient = require('auth0').ManagementClient

/**
 *
 * How this works:
 *  1. Requests an access token using client_id and client_secret
 *  2. Uses the access token to create a new ManagementClient
 *  3. Use the ManagementClient to interact with the API: https://auth0.github.io/node-auth0/module-management.ManagementClient.html
 *
 */

module.exports = (function () {
  let managementClient // eslint-disable-line

  return {
    init,
  }

  /**
   * Create a management client
   */
  function init() {
    return getToken()
      .then((data) => data.access_token)
      .then((token) => {
        const managementClient = new ManagementClient({
          domain: `${process.env.AUTH0_CLIENT_DOMAIN}`,
          token,
          audience: `https://${process.env.AUTH0_CLIENT_DOMAIN}/api/v2/`,
        })

        // set it so we can use it in our other methods
        this.managementClient = managementClient
        return true
      })
      .catch((err) => err)
  }

  /**
   * Get an access token from the Auth0 API
   * We will use this access token to connect to the management API
   * To get a token, we need to provide client_id and client_secret
   * Both of these can be found in the APIs section of Auth0 dashboard
   */
  function getToken() {
    // get the info we need
    const clientId = process.env.AUTH0_CLIENT_ID
    const clientSecret = process.env.AUTH0_CLIENT_SECRET
    const url = `https://${process.env.AUTH0_CLIENT_DOMAIN}/oauth/token`

    // make the call to the API via POST
    return axios
      .post(url, {
        client_id: clientId,
        client_secret: clientSecret,
        grant_type: 'client_credentials',
        scope: 'read:users update:users',
        audience: `https://${process.env.AUTH0_CLIENT_DOMAIN}/api/v2/`,
      })
      .then((res) => res.data)
      .catch((err) => console.log(err))
  }
})()
