// Set up some global config options

const contentfulConfig = {
  live: {
    space: process.env.NEXT_PUBLIC_CONTENTFUL_SPACE_ID,
    accessToken: process.env.NEXT_PUBLIC_CONTENTFUL_ACCESS_TOKEN,
  },
  preview: {
    space: process.env.NEXT_PUBLIC_CONTENTFUL_SPACE_ID,
    accessToken: process.env.NEXT_PUBLIC_CONTENTFUL_PREVIEW_ACCESS_TOKEN,
    host: 'preview.contentful.com',
  },
  global: {
    space: process.env.NEXT_PUBLIC_GLOBAL_CONTENTFUL_SPACE_ID,
    accessToken: process.env.NEXT_PUBLIC_GLOBAL_CONTENTFUL_ACCESS_TOKEN,
  },
}

// Query the GraphQL API

async function fetchContent(query, config) {
  return new Promise((resolve, reject) => {
    try {
      fetch(
        `https://graphql.contentful.com/content/v1/spaces/${config.space}`,
        {
          method: 'POST',
          headers: {
            'content-type': 'application/json',
            authorization: `Bearer ${config.accessToken}`,
          },
          body: JSON.stringify({ query }),
        }
      ).then((response) => {
        response.json().then((data) => {
          if (data.errors) {
            reject(data.data)
          } else {
            resolve(data.data)
          }
        })
      })
    } catch (error) {
      reject(error)
    }
  })
}

// Run a paginated content request

async function fetchPaginatedContent(
  collection,
  perPage,
  page,
  order,
  config,
  fields
) {
  const skipMultiplier = page === 1 ? 0 : page - 1
  const skip = skipMultiplier > 0 ? perPage * skipMultiplier : 0

  const query = `{
      ${collection}(limit: ${perPage}, skip: ${skip}, order: ${order}) {
        ${fields}
      }
    }`

  const response = await fetchContent(query, config)

  const paginatedEntries = response[collection]
    ? response[collection]
    : { total: 0, items: [] }

  return paginatedEntries
}

// Get total entries for a collection

async function getTotal(collection, config) {
  const query = `
    {
      ${collection} {
        total
      }
    }
  `

  const response = await fetchContent(query, config)

  const total = response[collection].total ? response[collection].total : 0

  return total
}

export { fetchContent, fetchPaginatedContent, getTotal, contentfulConfig }
